import { createRspackHtmlApp, rspack } from "@esmx/rspack";
import { VueLoaderPlugin as VueLoader2Plugin } from "vue2-loader";
import { VueLoaderPlugin as VueLoader3Plugin } from "vue3-loader";
import { vue2Loader } from "./vue2-loader.mjs";
import { vue3Loader } from "./vue3-loader.mjs";
export function createRspackVueApp(esmx, vueType, options) {
  return createRspackHtmlApp(esmx, {
    ...options,
    loaders: {
      styleLoader: new URL(import.meta.resolve("vue-style-loader")).pathname,
      ...options?.loaders
    },
    config(context) {
      const { config, buildTarget } = context;
      config.resolve = {
        ...config.resolve,
        extensions: [...config.resolve?.extensions ?? [], ".vue"]
      };
      config.plugins = config.plugins || [];
      switch (vueType) {
        case "2":
          config.plugins.push(new VueLoader2Plugin());
          break;
        case "3":
          config.plugins.push(new VueLoader3Plugin());
          break;
      }
      if (buildTarget === "client") {
        config.plugins.push(
          new rspack.DefinePlugin({
            "process.env.VUE_ENV": JSON.stringify(buildTarget)
          })
        );
      }
      const vueRuleUse = [
        {
          loader: new URL(import.meta.resolve(`vue${vueType}-loader`)).pathname,
          options: {
            ...options?.vueLoader,
            experimentalInlineMatchResource: true,
            optimizeSSR: buildTarget === "server"
          }
        }
      ];
      switch (vueType) {
        case "2":
          vueRuleUse.unshift(vue2Loader);
          break;
        case "3":
          vueRuleUse.unshift(vue3Loader);
          break;
      }
      config.module = {
        ...config.module,
        rules: [
          ...config.module?.rules ?? [],
          {
            test: /\.vue$/,
            use: vueRuleUse
          }
        ]
      };
      let vueAlias = null;
      switch (vueType) {
        case "2":
          vueAlias = "vue/dist/vue.esm.js";
          break;
        case "3":
          vueAlias = "vue/dist/vue.runtime.esm-browser.js";
          break;
      }
      if (vueAlias) {
        config.resolve.alias = {
          ...config.resolve.alias,
          vue$: vueAlias
        };
      }
      if (vueType === "2") {
        config.ignoreWarnings = [
          ...config.ignoreWarnings ?? [],
          (warning) => {
            return warning.moduleDescriptor.name.includes(
              "vue-server-renderer"
            );
          }
        ];
      }
      options?.config?.(context);
    }
  });
}
